==> haskell-entropy-0.4.1.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.4.1.3
id: entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
key: entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A mostly platform independent (not GHCJS) method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
abi: a55ec7d342356afca4f8cc8fa89eea9d
exposed: True
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
import-dirs: /usr/lib/ghc-8.4.3/site-local/entropy-0.4.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/entropy-0.4.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/entropy-0.4.1.3
hs-libraries: HSentropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
depends:
    base-4.11.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.4.1.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.4.1.3
id: entropy-0.4.1.3-IxkqMjuefoT8uP0p0wmXuD
key: entropy-0.4.1.3-IxkqMjuefoT8uP0p0wmXuD
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A mostly platform independent (not GHCJS) method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
abi: 7d66990dd96104baaa667e9e0bcbb64d
exposed: True
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
import-dirs: /usr/lib/ghc-8.6.1/site-local/entropy-0.4.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/entropy-0.4.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/entropy-0.4.1.3
hs-libraries: HSentropy-0.4.1.3-IxkqMjuefoT8uP0p0wmXuD
depends:
    base-4.12.0.0 bytestring-0.10.8.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
